@@ -4,14 +4,26 @@ import torch
 from inspect import signature
 
 
+def _identity(*args):
+    return args
+
+
+class _ImageOnlyTransform:
+    def __init__(self, transform):
+        self._transform = transform
+
+    def __call__(self, image, boxes):
+        return self._transform(image), boxes
+
+
 class Dataset(torch.utils.data.Dataset, ABC):
     def __init__(self, transform=None):
         super().__init__()
 
         if not transform:
-            self._transform = lambda x, y: (x, y)
+            self._transform = _identity
         elif len(signature(transform).parameters) == 1:
-            self._transform = lambda x, y: (transform(x), y)
+            self._transform = _ImageOnlyTransform(transform)
         else:
             self._transform = transform
 
@@ -29,7 +41,7 @@ class Dataset(torch.utils.data.Dataset, ABC):
 
     @transform.setter
     def transform(self, val):
-        self._transform = val if val else lambda x, y: (x, y)
+        self._transform = val if val else _identity
 
     def close(self):
         """Release the resources allocated for this dataset."""
